---
title: <span class="badge object-type-scalar"></span> BytesIEC
---
# <span class="badge object-type-scalar"></span> BytesIEC

Data: bytes(IEC)

## Definition

```python
# Data: bytes(IEC)
BytesIEC: typing.Literal["bytes"] = "bytes"
```
